@@ -36,7 +36,7 @@ class flux_cls:
     """ primary data management class
 
     * converts a list of lists (a matrix) to a list of flux_row_cls objects
-    * similar to a pandas DataFrame, but optimized for row-major ordered operations
+    * similar to a pandas DataFrame, but optimized for row-major ordered operations (df.iterrows())
 
     eg:
         matrix = [['col_a', 'col_b', 'col_c'],
@@ -59,9 +59,10 @@ class flux_cls:
     def __init__(self, matrix=None):
         matrix  = self.__validate_matrix(matrix)
         headers = self.__validate_matrix_headers(matrix[0])
+        matrix  = [flux_row_cls(headers, row) for row in matrix]
 
         self.headers = headers
-        self.matrix  = [flux_row_cls(headers, row) for row in matrix]
+        self.matrix  = matrix
 
     def __flux_headers_and_matrix(self, matrix, headers=None):
         matrix = self.__validate_matrix(matrix)
@@ -187,6 +188,9 @@ class flux_cls:
                       *,
                       fkwargs=None):
 
+        # h = self.header_names
+        # j = [ordereddict(zip(h, row.values)) for row in self.matrix[1:]]
+
         j = [row.dict() for row in self.matrix[1:]]
         if path is None:
             return json_dumps_extended(j, **fkwargs)
@@ -199,13 +203,48 @@ class flux_cls:
                        encoding=None,
                        *,
                        fkwargs=None):
+        """
+        if isinstance(j, dict):
+            {"col_a": "col_b",
+             "a": "b",
+             "a": "b",
+             "a": "b"}
 
+            items = iter(j.items())
+            m = [list(next(items))] + \
+                [list(item) for item in items]
+        else:
+            [
+                {"col_a": "a",
+                 "col_b": "b"},
+                {"col_a": "a",
+                 "col_b": "b"}
+            ]
+        """
         j = read_file(path, encoding, filetype='.json', fkwargs=fkwargs)
+
+        if isinstance(j, dict):
+            raise TypeError('json data should be a list of dictionaries, eg: '
+                            '\n['
+                            '\n\t{"col_a": "a",'
+                            '\n\t "col_b": "b"},'
+                            '\n\t{"col_a": "a",'
+                            '\n\t "col_b": "b"}'
+                            '\n]'
+                            '\n\nalternatively, json data could be converted to a matrix, eg: '
+                            '\n\tj = read_file(path)'
+                            '\n\tm = [list(row) for row in j.items()]'
+                            '\n\tflux = flux_cls(m)')
+
         if not j:
             m = [[]]
         else:
-            m = [list(j[0].keys())] + \
-                [list(row.values()) for row in j]
+            first_row = j[0]
+            if isinstance(first_row, dict):
+                m = [list(first_row.keys())] + \
+                    [list(row.values()) for row in j]
+            else:
+                m = j
 
         return cls(m)
 
@@ -233,12 +272,25 @@ class flux_cls:
     def columns(self, *names):
         names = self.__standardize_variable_arity_arguments(names, 1)
 
+        rva = self.row_values_accessor(names)
+        col = (rva(row) for row in self.matrix[1:])
+
         is_single_column = (iteration_depth(names) == 1
                             and len(names) == 1)
+        if not is_single_column:
+            col = list(col)
+            col = transpose_to_lists(col)
+
+        return col
+
+    def columns2(self, *names):
+        names = self.__standardize_variable_arity_arguments(names, 1)
 
         rva = self.row_values_accessor(names)
         col = [rva(row) for row in self.matrix[1:]]
 
+        is_single_column = (iteration_depth(names) == 1
+                            and len(names) == 1)
         if not is_single_column:
             col = list(transpose_to_lists(col))
 
