@@ -1,4 +1,11 @@
 
+# from ..conditional import is_pypy
+
+# if not is_pypy:
+#
+# else:
+#
+
 from datetime import date
 from datetime import datetime
 
@@ -8,10 +15,10 @@ from pythoncom import com_error as pythoncom_error
 from .excel_constants import *
 from .workbook import excel_application_to_foreground
 
-from ..excel_com.excel_address import col_letter
-from ..excel_com.excel_address import col_number
-from ..excel_com.excel_address import max_cols as excel_max_cols
-from ..excel_com.excel_address import max_rows as excel_max_rows
+from .excel_address import col_letter
+from .excel_address import col_number
+from .excel_address import max_cols as excel_max_cols
+from .excel_address import max_rows as excel_max_rows
 
 from ..util.iter import iterator_to_list
 from ..util.iter import modify_iteration_depth
@@ -231,6 +238,7 @@ def convert_python_types(m):
             convert non-primitives to repr()
     """
     # region {closure function}
+    # noinspection PyPep8Naming
     NoneType = type(None)
 
     def convert_excel_value(v):
