@@ -1,5 +1,7 @@
 
-import _pickle as cpickle
+from .. conditional import cpickle
+from .. conditional import ultrajson_installed
+
 import csv
 import gc
 import os
@@ -12,22 +14,14 @@ from json import JSONDecodeError
 from glob import glob
 from string import ascii_lowercase
 
-from .text import json_unhandled_conversion
+from . text import json_unhandled_conversion
 
-from .. conditional import ultrajson_installed
 if ultrajson_installed:
     import ujson as json
 else:
     import json
 
 pickle_extensions = {'.flux', '.pkl', '.pickle'}
-notimplemented_extensions = {'.7z',
-                             '.gzip',
-                             '.png',
-                             '.jpg',
-                             '.jpeg',
-                             '.gif',
-                             '.pdf'}
 
 
 def read_file(path,
@@ -149,6 +143,14 @@ def write_file(path,
 
 def __validate_filetype(filetype, path):
     """ check for file types that require specialized io libraries / protocols """
+    notimplemented_extensions = {'.7z',
+                                 '.gzip',
+                                 '.png',
+                                 '.jpg',
+                                 '.jpeg',
+                                 '.gif',
+                                 '.pdf'}
+
     filetype = filetype or parse_file_extension(path, include_dot=True)
     filetype = filetype.lower().strip()
 
@@ -199,13 +201,16 @@ def __read_limited_csv_rows(nrows, csv_reader):
 
 def clear_dir(filedir):
     filedir = standardize_dir(filedir, explicit_cwd=True)
+
     if not os.path.exists(filedir):
         return
 
-    del_paths = [filedir + item for item in os.listdir(filedir)]
-    del_paths.sort(reverse=True)
+    if not os.path.isdir(filedir):
+        raise TypeError('"{}" is not a directory'.format(filedir))
+
+    for item in os.listdir(filedir):
+        path = filedir + item
 
-    for path in del_paths:
         if os.path.isdir(path):
             shutil.rmtree(path)
         else:
@@ -231,7 +236,8 @@ def copy_dir(s_dir, d_dir, ignore=None, dirs_exist_ok=False):
     if not dirs_exist_ok and os.path.exists(d_dir):
         shutil.rmtree(d_dir)
 
-    shutil.copytree(src=s_dir, dst=d_dir,
+    shutil.copytree(src=s_dir,
+                    dst=d_dir,
                     ignore=ignore,
                     dirs_exist_ok=dirs_exist_ok)
 
@@ -246,45 +252,54 @@ def file_modified_datetime(path):
     return datetime.fromtimestamp(unix_t)
 
 
-def parse_path(path, pathsep='/', explicit_cwd=False):
+def parse_path(path,
+               pathsep='/',
+               explicit_cwd=False):
 
     ParsedPath = namedtuple('ParsedPath', ('directory',
                                            'filename',
                                            'extension'))
     if os.path.isdir(path):
-        filedir  = path
-        filename = ''
+        filedir   = path
+        filename  = ''
+        extension = ''
     else:
-        filedir, filename = os.path.split(path)
+        filedir,  filename  = os.path.split(path)
+        filename, extension = os.path.splitext(filename)
 
-    filedir  = standardize_dir(filedir, pathsep, explicit_cwd)
-    filename = standardize_file_name(filename)
-    filename, extn = os.path.splitext(filename)
+    filedir = standardize_dir(filedir, pathsep, explicit_cwd)
 
-    parsed_path = ParsedPath(filedir, filename, extn)
-
-    return parsed_path
+    return ParsedPath(filedir, filename, extension)
 
 
-def standardize_path(path, pathsep='/', explicit_cwd=False):
-    filedir, filename, extn = parse_path(path, pathsep, explicit_cwd)
+def parse_file_extension(filename, include_dot=True):
+    _, extension = os.path.splitext(filename)
+    if (include_dot is False) and (extension.startswith('.')):
+        extension = extension[1:]
 
-    return filedir + filename + extn
+    return extension
 
 
-def standardize_dir(filedir, pathsep='/', explicit_cwd=False):
+def standardize_path(path,
+                     pathsep='/',
+                     explicit_cwd=False):
 
-    is_filedir_empty = (filedir == '')
-    if not explicit_cwd and is_filedir_empty:
+    p_path = parse_path(path, pathsep, explicit_cwd)
+    path   = ''.join(p_path)
+
+    return path
+
+
+def standardize_dir(filedir,
+                    pathsep='/',
+                    explicit_cwd=False):
+
+    if (explicit_cwd is False) and (filedir == ''):
         return filedir
 
-    if is_filedir_empty:
-        filedir = os.getcwd()
-
+    filedir = filedir or os.getcwd()
     filedir = (filedir.replace('\\', pathsep)
-                      .replace('/', pathsep)
-                      .lower()
-                      .strip())
+                      .replace('/', pathsep))
 
     if not filedir.endswith(pathsep):
         filedir += pathsep
@@ -299,40 +314,30 @@ def standardize_dir(filedir, pathsep='/', explicit_cwd=False):
     return filedir
 
 
-def standardize_file_name(filename):
-    return filename.lower().strip()
-
-
-def parse_file_extension(filename, include_dot=True):
-    filename = standardize_file_name(filename)
-    _, extn = os.path.splitext(filename)
-
-    if include_dot is False:
-        extn = extn.replace('.', '', 1)
-
-    return extn
-
-
 def validate_path_exists(path):
-    filedir, filename, extn = parse_path(path, pathsep='/', explicit_cwd=True)
+
+    (filedir,
+     filename,
+     extension) = parse_path(path, explicit_cwd=True)
 
     if not os.path.exists(filedir):
         raise FileNotFoundError('directory not found: \n\t{}'.format(filedir))
 
-    path = filedir + filename + extn
+    path = filedir + filename + extension
 
     if not os.path.exists(path):
         glob_paths = glob(filedir + filename + '.*')
         if glob_paths:
-            extn = parse_file_extension(os.path.split(glob_paths[0])[1], include_dot=True)
+
+            extension = parse_file_extension(os.path.split(glob_paths[0])[1], include_dot=True)
             raise FileNotFoundError('file extension not found: '
                                     '\n\t{}'
                                     '\n\t{}'
-                                    '\n\tdid you mean: {}?'.format(filedir, filename, extn))
+                                    '\n\tdid you mean: {}?'.format(filedir, filename, extension))
 
         raise FileNotFoundError('file not found: '
                                 '\n\t{}'
-                                '\n\t{}'.format(filedir, filename + extn))
+                                '\n\t{}'.format(filedir, filename + extension))
 
     return path
 
